@@ -34,7 +34,6 @@ class Repository:
         Arguments: <data> - collection or single model
         Returns: last id inserted or updated
         '''
-        response = None
         data = entity
 
         #region entity
@@ -42,6 +41,8 @@ class Repository:
         model = self.update(entity_from_database=model_from_database, entity=data)
 
         if model not in self.session:
+            self.session.add(model)
+        else:
             self.session.merge(model)
 
         entity_type = type(model)
