@@ -6,9 +6,9 @@ class Parser:
 
     scraper = None
 
-    def __init__(self, config: Config, user_dir: str=None, headless: bool=True, window: dict={}) -> None:
+    def __init__(self, config: Config, user_dir: str=None, headless: bool=True, disable_javascript: bool=False, window: dict={}) -> None:
         self.config = config
-        self.scraper = self.get_scraper(config=config, headless=headless, window=window, user_dir=user_dir)
+        self.scraper = self.get_scraper(config=config, headless=headless, disable_javascript=disable_javascript, window=window, user_dir=user_dir)
 
     # region methods
     def click(self, path: str, element: any=None, timeout: int=0) -> any:
@@ -73,7 +73,7 @@ class Parser:
 
     #endregion methods
 
-    def get_scraper(self, config: Config, user_dir: str=None, headless: bool=True, window: dict={}) -> Scraper:
+    def get_scraper(self, config: Config, user_dir: str=None, headless: bool=True, disable_javascript: bool=False, window: dict={}) -> Scraper:
         scraper_type = self.config.get('PROJECT', 'scraper')
         if scraper_type is not None:
             module_name = self.config.get('PROJECT', 'scraper')
@@ -82,4 +82,4 @@ class Parser:
             module_name = 'selenium'
             class_name = 'Selenium'
 
-        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'window': window, 'config': config, 'user_dir': user_dir })
\ No newline at end of file
+        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'disable_javascript': disable_javascript, 'window': window, 'config': config, 'user_dir': user_dir })
\ No newline at end of file
